@@ -4,26 +4,42 @@
 
 extern crate plugger_ruby;
 extern crate plugger_core;
+extern crate rurust;
 
 use std::io::Write;
+use rurust::Value;
 
 #[pluggable]
 struct Animal {
-    a: u32,
+    pub a: u32,
 }
 
 #[pluggable]
 impl Animal
 {
-    pub fn woof() { println!("woof!"); }
-    pub fn meow() { println!("meow!"); }
+    #[plug]
+    pub fn woof() -> Value {
+        Value::nil()
+    }
+
+    #[plug]
+    pub fn meow() -> Value {
+        println!("meow!");
+        Value::string("meooooooow")
+    }
+
+    #[plug]
+    pub fn moo(&self) -> Value {
+        println!("moo!! = {}", self.a);
+        Value::fixnum(self.a as _)
+    }
 }
 
 fn main() {
-    let mut animal = Animal { a: 0 };
+    let mut animal = Animal { a: 512 };
 
     let mut ruby = plugger_ruby::Ruby::new().unwrap();
-    ruby.plug(&mut animal);
+    ruby.plug("animal", &mut animal);
 
     loop {
         let mut line = String::new();
